# actorcore

Provides core services used by most actors. `actorcore` and `opscore` provide direct dependencies for the actors, while `actorkeys` provides the definitions of standard messages that will be broadcast by each actor.

## Installation

To install using `pip`

```(console)
pip install sdss-actorcore
```

To install from source

```(console)
git clone git@github.com:sdss/actorcore
cd actorcore
pip install .
```
